@@ -1,13 +1,11 @@
 import json
-import os
 from flask import Blueprint
 from flask import Response
 from flask.ext.cors import cross_origin
 from pgeo.error.custom_exceptions import PGeoException
 from pgeo.error.custom_exceptions import errors
 from pgeo.config.settings import read_config_file_json
-from pgeo.config.settings import settings
-
+from pgeo.utils.filesystem import list_sources
 
 schema = Blueprint('schema', __name__)
 
@@ -21,18 +19,12 @@ def index():
 @schema.route('/sources', methods=['GET'])
 @schema.route('/sources/', methods=['GET'])
 @cross_origin(origins='*')
-def list_sources():
+def list_sources_service():
     try:
-        path = os.path.join(os.path.dirname(os.path.dirname(__file__)) + '/' + settings['folders']['config'] + settings['folders']['data_providers'])
-        out = []
-        files = os.listdir(path)
-        files.sort()
-        for filename in files:
-            out.append({'code': filename, 'label': filename[:filename.index('.json')]})
+        out = list_sources()
         return Response(json.dumps(out), content_type='application/json; charset=utf-8')
-    except Exception, err:
-        print err
-        raise PGeoException(errors[510], status_code=510)
+    except PGeoException, e:
+        raise PGeoException(e.get_message(), e.get_status_code())
 
 
 @schema.route('/sources/<source_name>', methods=['GET'])
